/**
 * @public
 *
 * 插件对象实例。调用 `SegPlugin.inject` 成功后会返回一个插件实例。
 */
export declare interface IVirtualBackgroundEffectInstance {
    /**
     * 插件实例是否被销毁。
     *
     * 一般只有在插件实例所对应的本地视频轨道被 close 时，插件实例会一起被销毁。
     *
     */
    isDestroyed: boolean;
    /**
     * 设置插件实例的属性。
     * @param options 详见 {@link VirtualBackgroundEffectOptions}。
     */
    setOptions(options: VirtualBackgroundEffectOptions): void;
    /**
     * 获取插件实例的属性。
     */
    getOptions(): VirtualBackgroundEffectOptions;
}

/**
 * @public
 * 插件对象。一个浏览器页面里只会用一个插件对象，插件对象需要初始化后才能使用。
 *
 */
export declare interface IVirtualBackgroundPlugin {
    /**
     * 插件是否初始化。
     */
    hasInit: boolean;
    /**
     * 将插件注入一个本地视频轨道（localVideoTrack 对象）。
     *
     * @param track 本地视频轨道对象。
     * @param wasmDir 虚拟背景插件所依赖的 wasm 文件的 URI 地址。
     * @return {@link IVirtualBackgroundEffectInstance} 的实例。
         */
     inject(track: any, wasmDir: string): Promise<IVirtualBackgroundEffectInstance>;
     /**
      * 获取一个视频轨道对象所对应的插件实例，插件实例可用于设置虚拟背景插件属性。
      *
      * @param track 本地视频轨道对象。
      * @return {@link IVirtualBackgroundEffectInstance} 的实例。
          */
      getInstanceByTrack(track: any): IVirtualBackgroundEffectInstance | null;
     }

     declare const plugin: IVirtualBackgroundPlugin;
     export default plugin;

     /**
      * @public
      *
      * 插件实例的属性。用于 {@link setOptions} 方法。
      */
     export declare type VirtualBackgroundEffectOptions = {
         /**
          * 是否开启虚拟背景。
          */
         enable?: boolean;
         /**
          * 设置自定义背景图。
          *
          * 如果出现 "texture bound to texture unit 2 is not renderable. It might be non-power-of-2 or have incompatible texture filtering (maybe)?" 报错，请检查图片的分辨率相乘后是否是 2 的倍数。
          */
         background?: HTMLImageElement | null;
     };

     export { }
