/**
 * The class of the plugin instance object. A successful call of `SegPlugin.inject` returns a plugin instance.
 */
export declare interface IVirtualBackgroundEffectInstance {
    /**
     *
     * Whether the plugin instance is destroyed.
     *
     * Usually a plugin instance is destroyed when the corresponding video track has been closed.
     */
    isDestroyed: boolean;
    /**
     * Sets the plugin options.
     * @param options See {@link VirtualBackgroundEffectOptions}.
     */
    setOptions(options: VirtualBackgroundEffectOptions): void;
    /**
     * Gets the plugin options.
     */
    getOptions(): VirtualBackgroundEffectOptions;
}

/**
 * The plugin class.
 *
 * You can only use one plugin object on one webpage.
 *
 * The plugin object must be initiated before use.
 */
export declare interface IVirtualBackgroundPlugin {
    /**
     * Whether the plugin is initiated.
     */
    hasInit: boolean;
     /**
      * Injects the plugin into a local video track.
      * @param track A local video track object.
      * @param wasmDir the uri containing all the virtual background wasm files
      * @return An instance of {@link IVirtualBackgroundEffectInstance}.
      */
     inject(track: any, wasmDir: string): Promise<IVirtualBackgroundEffectInstance>;
      /**
       * Gets the plugin instance of a local video track.
       *
       * @param track A local video track object.
       * @return An instance of {@link IVirtualBackgroundEffectInstance}.
       */
      getInstanceByTrack(track: any): IVirtualBackgroundEffectInstance | null;
     }

     declare const plugin: IVirtualBackgroundPlugin;
     export default plugin;

     /**
      * Options of the virtual background plugin. Used when calling {@link setOptions}.
      */
     export declare type VirtualBackgroundEffectOptions = {
         /**
          * Whether to enable the virtual background.
          */
         enable?: boolean;
         /**
          * Sets the background image.
          *
          * If the error "texture bound to texture unit 2 is not renderable. It might be non-power-of-2 or have incompatible texture filtering (maybe)?" appears, please check whether the product of the picture's width and height is a multiple of 2.
          */
         background?: HTMLImageElement | null;
     };

     export { }
