// create Agora client
console.log(SegPlugin);
var client = AgoraRTC.createClient({mode: "rtc", codec: "vp8"});
AgoraRTC.loadModule(SegPlugin, {});

var localTracks = {
  videoTrack: null,
  audioTrack: null
};
var remoteUsers = {};
// Agora client options
var options = {
  appid: null,
  channel: null,
  uid: null,
  token: null
};
var virtualBackgroundEnabled = false;
var virtualBackgroundInstance;

// the demo can auto join channel with params in url
$(() => {
  var urlParams = new URL(location.href).searchParams;
  options.appid = urlParams.get("appid");
  options.channel = urlParams.get("channel");
  options.token = urlParams.get("token");
  if (options.appid && options.channel) {
    $("#appid").val(options.appid);
    $("#token").val(options.token);
    $("#channel").val(options.channel);
    $("#join-form").submit();
  }
})

$("#join-form").submit(async function (e) {
  e.preventDefault();
  $("#join").attr("disabled", true);
  try {
    options.appid = $("#appid").val();
    options.token = $("#token").val();
    options.channel = $("#channel").val();
    await join();
    if (options.token) {
      $("#success-alert-with-token").css("display", "block");
    } else {
      $("#success-alert a").attr("href", `index.html?appid=${options.appid}&channel=${options.channel}&token=${options.token}`);
      $("#success-alert").css("display", "block");
    }
  } catch (error) {
    console.error(error);
  } finally {
    $("#leave").attr("disabled", false);
  }
})

$("#leave").click(function (e) {
  leave();
})

$("#background-blurring").click(async function () {
  if (localTracks.videoTrack) {
    document.getElementById("loading").style.display = "block";
    if (!virtualBackgroundInstance) {
      virtualBackgroundInstance = await SegPlugin.inject(localTracks.videoTrack, "./assets/wasms");
    }
    virtualBackgroundInstance.setOptions({enable: true});
    document.getElementById("loading").style.display = "none";
    virtualBackgroundEnabled = true;
  }
});

$("#virtual-background-off").click(async function () {
  if (localTracks.videoTrack && virtualBackgroundEnabled) {
    virtualBackgroundInstance.setOptions({enable: false});
    virtualBackgroundEnabled = false;
  }
});

$("#image-uploader").click(function() {
  document.querySelector('#image-uploader').value = "";
});
$("#image-uploader").change(async function(){
  if (localTracks.videoTrack) {
    $(".image-name").text(`background image: ${this.files[0].name}`);

    const imageUploader = document.querySelector('#image-uploader');
    const image = imageUploader.files[0];
    const imgElement = document.createElement('img');

    if(!image){
      return;
    }

    imgElement.onload = async() => {
      document.getElementById("loading").style.display = "block";
      if (!virtualBackgroundInstance) {
        virtualBackgroundInstance = await SegPlugin.inject(localTracks.videoTrack, "./assets/wasms");
      }
      virtualBackgroundInstance.setOptions({enable: true,... image && {background:imgElement}});

      document.getElementById("loading").style.display = "none";
      virtualBackgroundEnabled = true;
    }
    const url = URL.createObjectURL(image);
    imgElement.src = url;
  }
});

async function join() {

  // add event listener to play remote tracks when remote user publishs.
  client.on("user-published", handleUserPublished);
  client.on("user-unpublished", handleUserUnpublished);

  // join a channel and create local tracks, we can use Promise.all to run them concurrently
  [options.uid, localTracks.audioTrack, localTracks.videoTrack] = await Promise.all([
    // join the channel
    client.join(options.appid, options.channel, options.token || null),
    // create local tracks, using microphone and camera
    localTracks.audioTrack || AgoraRTC.createMicrophoneAudioTrack(),
    localTracks.videoTrack || AgoraRTC.createCameraVideoTrack()
  ]);

  // play local video track
  localTracks.videoTrack.play("local-player");
  $("#local-player-name").text(`localVideo(${options.uid})`);

  // publish local tracks to channel
  await client.publish(Object.values(localTracks));

  $("#background-blurring").attr("disabled", false);
  $("#image-uploader").attr("disabled", false);
  $("#virtual-background-off").attr("disabled", false);
  console.log("publish success");
}

async function leave() {
  // remove remote users and player views
  remoteUsers = {};
  $("#remote-playerlist").html("");

  // leave the channel
  await client.leave();

  $("#local-player-name").text("");
  $("#join").attr("disabled", false);
  $("#leave").attr("disabled", true);
  $("#background-blurring").attr("disabled", true);
  $("#image-uploader").attr("disabled", true);
  $("#virtual-background-off").attr("disabled", true);
  console.log("client leaves channel success");

  virtualBackgroundEnabled = false;
  virtualBackgroundInstance.setOptions({enable:false});
}

async function subscribe(user, mediaType) {
  const uid = user.uid;
  // subscribe to a remote user
  await client.subscribe(user, mediaType);
  console.log("subscribe success");
  if (mediaType === 'video') {
    const player = $(`
      <div id="player-wrapper-${uid}">
        <p class="player-name">remoteUser(${uid})</p>
        <div id="player-${uid}" class="player"></div>
      </div>
    `);
    $("#remote-playerlist").append(player);
    user.videoTrack.play(`player-${uid}`);
  }
  if (mediaType === 'audio') {
    user.audioTrack.play();
  }
}

function handleUserPublished(user, mediaType) {
  const id = user.uid;
  remoteUsers[id] = user;
  subscribe(user, mediaType);
}

function handleUserUnpublished(user) {
  const id = user.uid;
  delete remoteUsers[id];
  $(`#player-wrapper-${id}`).remove();
}
